@@ -31,12 +31,25 @@
 #include <QMetaObject>
 #include <QMetaProperty>
 #include <QTimeZone>
-#include <QVariant>
 
 #include <cmath>
 #include <cstring>
 #include <set>
 
+namespace KItinerary {
+struct CompareFunc {
+    int metaTypeId;
+    std::function<bool(const QVariant &, const QVariant &)> func;
+};
+
+static bool operator<(const CompareFunc &lhs, int rhs)
+{
+    return lhs.metaTypeId < rhs;
+}
+
+static std::vector<CompareFunc> s_mergeCompareFuncs;
+}
+
 using namespace KItinerary;
 
 /* Checks that @p lhs and @p rhs are non-empty and equal. */
@@ -60,10 +73,17 @@ static bool conflictIfPresent(const T &lhs, const T &rhs)
 {
     return lhs.isValid() && rhs.isValid() && lhs != rhs;
 }
+static bool conflictIfPresent(const Person &lhs, const Person &rhs)
+{
+    return !lhs.name().isEmpty() && !rhs.name().isEmpty() && !MergeUtil::isSamePerson(lhs, rhs);
+}
 
 /** Checks that @p lhs and @p rhs have a different prefix is they are both set. */
-template <typename T>
-static bool prefixConflictIfPresent(const T &lhs, const T &rhs)
+static bool prefixConflictIfPresent(const QString &lhs, const QString &rhs, Qt::CaseSensitivity caseSensitive = Qt::CaseSensitive)
+{
+    return !lhs.isEmpty() && !rhs.isEmpty() && !lhs.startsWith(rhs, caseSensitive) && !rhs.startsWith(lhs, caseSensitive);
+}
+static bool prefixConflictIfPresent(const QByteArray &lhs, const QByteArray &rhs)
 {
     return !lhs.isEmpty() && !rhs.isEmpty() && !lhs.startsWith(rhs) && !rhs.startsWith(lhs);
 }
@@ -86,9 +106,8 @@ static bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs);
 bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
 {
     // underName either matches or is not set
-    const auto lhsUN = lhsRes.underName().value<Person>();
-    const auto rhsUN = rhsRes.underName().value<Person>();
-    if (!lhsUN.name().isEmpty() && !rhsUN.name().isEmpty() &&  !MergeUtil::isSamePerson(lhsUN, rhsUN)) {
+    if (conflictIfPresent(lhsRes.underName().value<Person>(), rhsRes.underName().value<Person>())
+     || conflictIfPresent(lhsRes.reservationNumber(), rhsRes.reservationNumber())) {
         return false;
     }
 
@@ -200,9 +219,6 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
     if (JsonLd::isA<LodgingReservation>(lhs)) {
         const auto lhsRes = lhs.value<LodgingReservation>();
         const auto rhsRes = rhs.value<LodgingReservation>();
-        if (lhsRes.reservationNumber() != rhsRes.reservationNumber()) {
-            return false;
-        }
         return isSame(lhsRes.reservationFor(), rhsRes.reservationFor()) && lhsRes.checkinTime().date() == rhsRes.checkinTime().date();
     }
     if (JsonLd::isA<LodgingBusiness>(lhs)) {
@@ -288,14 +304,8 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         const auto lhsTicket = lhs.value<Ticket>();
         const auto rhsTicket = rhs.value<Ticket>();
 
-        // underName either matches or is not set
-        const auto lhsUN = lhsTicket.underName();
-        const auto rhsUN = rhsTicket.underName();
-        if (!lhsUN.name().isEmpty() && !rhsUN.name().isEmpty() &&  !isSamePerson(lhsUN, rhsUN)) {
-            return false;
-        }
-
-        if (conflictIfPresent(lhsTicket.ticketNumber(), rhsTicket.ticketNumber())
+        if (conflictIfPresent(lhsTicket.underName(), rhsTicket.underName())
+         || conflictIfPresent(lhsTicket.ticketNumber(), rhsTicket.ticketNumber())
          || conflictIfPresent(lhsTicket.name(), rhsTicket.name())
          || conflictIfPresent(lhsTicket.validFrom(), rhsTicket.validFrom())
          || !isSameTicketToken(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())
@@ -304,6 +314,28 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         }
     }
 
+    // program memberships
+    if (JsonLd::isA<ProgramMembership>(lhs)) {
+        const auto lhsPM = lhs.value<ProgramMembership>();
+        const auto rhsPM = rhs.value<ProgramMembership>();
+
+        if (conflictIfPresent(lhsPM.member(), rhsPM.member())
+         || conflictIfPresent(lhsPM.programName(), rhsPM.programName())
+         || conflictIfPresent(lhsPM.membershipNumber(), rhsPM.membershipNumber())
+         || conflictIfPresent(lhsPM.validFrom(), rhsPM.validFrom())
+         || conflictIfPresent(lhsPM.validUntil(), rhsPM.validUntil())
+         || !isSameTicketToken(lhsPM.tokenData(), rhsPM.tokenData())
+        ) {
+            return false;
+        }
+    }
+
+    // custom comparators
+    const auto it = std::lower_bound(s_mergeCompareFuncs.begin(), s_mergeCompareFuncs.end(), lhs.userType());
+    if (it != s_mergeCompareFuncs.end() && (*it).metaTypeId == lhs.userType()) {
+        return (*it).func(lhs, rhs);
+    }
+
     return true;
 }
 
@@ -383,8 +415,17 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
         qCDebug(CompareLog) << "unbound trip" << lhs.departureStation().name() << rhs.departureStation().name() << lhs.arrivalStation().name() << rhs.arrivalStation().name();
         return LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact)
             && LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
-    } else if (!equalAndPresent(lhs.departureTime(), rhs.departureTime())) {
-        return false;
+    } else if (lhs.departureTime().isValid() && rhs.departureTime().isValid()) {
+        // if we have both departure times, they have to match
+        if (!equalAndPresent(lhs.departureTime(), rhs.departureTime())) {
+            return false;
+        }
+    } else {
+        // only one departure time exists, so check if the locations don't conflict and rely on the train number for the rest
+        if (!LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::CityLevel)
+            || !LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::CityLevel)) {
+            return false;
+        }
     }
 
     // arrival times (when present) should either match exactly, or be almost the same at a matching arrival location
@@ -409,7 +450,7 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
     qCDebug(CompareLog) << "left:" << lhs.trainName() << lhs.trainNumber() << lhs.departureTime();
     qCDebug(CompareLog) << "right:" << rhs.trainName() << rhs.trainNumber() << rhs.departureTime();
     qCDebug(CompareLog) << "same line:" << isSameLine;
-    return !conflictIfPresent(lhs.trainName(),rhs.trainName()) && isSameLine && lhs.departureTime().date() == rhs.departureTime().date();
+    return !conflictIfPresent(lhs.trainName(),rhs.trainName()) && isSameLine;
 }
 
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs)
@@ -577,13 +618,13 @@ static QVariantList mergeSubjectOf(const QVariantList &lhs, const QVariantList &
 {
     std::set<QString> mergedSet;
     for (const auto &v : lhs) {
-        if (v.type() != QVariant::String) {
+        if (v.userType() != QMetaType::QString) {
             return rhs.isEmpty() ? lhs : rhs;
         }
         mergedSet.insert(v.toString());
     }
     for (const auto &v : rhs) {
-        if (v.type() != QVariant::String) {
+        if (v.userType() != QMetaType::QString) {
             return rhs.isEmpty() ? lhs : rhs;
         }
         mergedSet.insert(v.toString());
@@ -597,10 +638,10 @@ static QVariantList mergeSubjectOf(const QVariantList &lhs, const QVariantList &
 
 static int ticketTokenSize(const QVariant &v)
 {
-    if (v.type() == QVariant::String) {
+    if (v.userType() == QMetaType::QString) {
         return v.toString().size();
     }
-    if (v.type() == QVariant::ByteArray) {
+    if (v.userType() == QMetaType::QByteArray) {
         return v.toByteArray().size();
     }
     return 0;
@@ -658,15 +699,15 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
             rv = mergeValue(lv.value<Airline>(), rv.value<Airline>());
         } else if (mt == qMetaTypeId<Person>()) {
             rv = mergeValue(lv.value<Person>(), rv.value<Person>());
-        } else if (mt == qMetaTypeId<QDateTime>()) {
+        } else if (mt == QMetaType::QDateTime) {
             rv = mergeValue(lv.toDateTime(), rv.toDateTime());
         } else if (mt == qMetaTypeId<Ticket>()) {
             rv = mergeValue(lv.value<Ticket>(), rv.value<Ticket>());
         } else if ((metaType.flags() & QMetaType::IsGadget) && metaType.metaObject()) {
             rv = merge(prop.readOnGadget(lhs.constData()), rv);
-        } else if (mt == QVariant::List && std::strcmp(prop.name(), "subjectOf") == 0) {
+        } else if (mt == QMetaType::QVariantList && std::strcmp(prop.name(), "subjectOf") == 0) {
             rv = mergeSubjectOf(lv.toList(), rv.toList());
-        } else if (mt == QVariant::String) {
+        } else if (mt == QMetaType::QString) {
             rv = StringUtil::betterString(lv.toString(), rv.toString()).toString();
         }
 
@@ -702,10 +743,10 @@ bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs)
         return false;
     }
 
-    if (lhs.type() == QVariant::String) {
-        return !prefixConflictIfPresent(lhs.toString(), rhs.toString());
+    if (lhs.userType() == QMetaType::QString) {
+        return !prefixConflictIfPresent(lhs.toString(), rhs.toString(), Qt::CaseInsensitive);
     }
-    if (lhs.type() == QVariant::ByteArray) {
+    if (lhs.userType() == QMetaType::QByteArray) {
         return !prefixConflictIfPresent(lhs.toByteArray(), rhs.toByteArray());
     }
 
@@ -747,3 +788,13 @@ bool MergeUtil::hasSameArrival(const QVariant &lhs, const QVariant &rhs)
 
     return LocationUtil::isSameLocation(LocationUtil::arrivalLocation(lhs), LocationUtil::arrivalLocation(rhs), LocationUtil::Exact);
 }
+
+void MergeUtil::registerComparator(int metaTypeId, std::function<bool (const QVariant&, const QVariant&)> &&func)
+{
+    auto it = std::lower_bound(s_mergeCompareFuncs.begin(), s_mergeCompareFuncs.end(), metaTypeId);
+    if (it != s_mergeCompareFuncs.end() && (*it).metaTypeId == metaTypeId) {
+        (*it).func = std::move(func);
+    } else {
+        s_mergeCompareFuncs.insert(it, {metaTypeId, std::move(func)});
+    }
+}
