@@ -11,12 +11,61 @@
 #include <QExplicitlySharedDataPointer>
 #include <QMetaType>
 
+#include <functional>
+
 class QImage;
 class QTransform;
 
 namespace KItinerary {
-
 class PdfImagePrivate;
+class PdfImageRef;
+}
+
+namespace std {
+template<>
+struct hash<KItinerary::PdfImageRef>
+{
+    inline std::size_t operator()(const KItinerary::PdfImageRef &ref) const noexcept;
+};
+}
+
+namespace KItinerary {
+
+/** PDF image element type. */
+enum class PdfImageType {
+    Image,
+    Mask,
+    SMask
+};
+
+/** PDF object reference for an image, with the ability to address attached masks as well. */
+class PdfImageRef
+{
+public:
+    constexpr PdfImageRef() = default;
+    constexpr inline PdfImageRef(int num, int gen, PdfImageType type = PdfImageType::Image)
+        : m_refNum(num)
+        , m_refGen(gen)
+        , m_type(type)
+    {}
+
+    constexpr inline bool isNull() const
+    {
+        return m_refNum < 0;
+    }
+
+    constexpr inline bool operator==(const PdfImageRef &other) const
+    {
+        return m_refNum == other.m_refNum && m_refGen == other.m_refGen && m_type == other.m_type;
+    }
+
+private:
+    int m_refNum = -1;
+    int m_refGen = -1;
+    PdfImageType m_type = PdfImageType::Image;
+    friend class PdfImagePrivate;
+    friend std::size_t std::hash<PdfImageRef>::operator ()(const PdfImageRef&) const noexcept;
+};
 
 /** An image in a PDF document.
  */
@@ -69,7 +118,7 @@ public:
      *  Use this to detect multiple occurrences of the same image in different
      *  places, if that reduces e.g. computation cost.
      */
-    int objectId() const;
+    PdfImageRef objectId() const;
 
     /** Returns whether this is a raster or vector image. */
     bool isVectorImage() const;
@@ -92,3 +141,8 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(PdfImage::LoadingHints)
 
 Q_DECLARE_METATYPE(KItinerary::PdfImage)
 
+std::size_t std::hash<KItinerary::PdfImageRef>::operator()(const KItinerary::PdfImageRef &ref) const noexcept
+{
+    // first part is how poppler hashes its Ref type
+    return std::hash<int>{}(ref.m_refNum) ^ (std::hash<int>{}(ref.m_refGen) << 1) ^ std::hash<int>{}((int)ref.m_type);
+}
