@@ -17,6 +17,8 @@
 #include <KItinerary/Ticket>
 
 #include <knowledgedb/airportdb.h>
+#include <text/nameoptimizer_p.h>
+#include <text/timefinder_p.h>
 
 #include <KPkPass/Barcode>
 #include <KPkPass/BoardingPass>
@@ -127,11 +129,12 @@ static bool isPlausibeGate(const QString &s)
 static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
 {
     // search for missing information by field key
+    TimeFinder timeFinder;
     const auto fields = pass->fields();
     for (const auto &field : fields) {
         // boarding time
         if (!flight.boardingTime().isValid() && field.key().contains(QLatin1String("boarding"), Qt::CaseInsensitive)) {
-            const auto time = QTime::fromString(field.value().toString());
+            const auto time = timeFinder.findSingularTime(field.value().toString());
             if (time.isValid()) {
                 // this misses date, but the postprocessor will fill that in
                 flight.setBoardingTime(QDateTime(QDate(1, 1, 1), time));
@@ -148,7 +151,7 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
         }
         // departure time
         if (!flight.departureTime().isValid() && field.key().contains(QLatin1String("departure"), Qt::CaseInsensitive)) {
-            const auto time = QTime::fromString(field.value().toString());
+            const auto time = timeFinder.findSingularTime(field.value().toString());
             if (time.isValid()) {
                 // this misses date, but the postprocessor will fill that in
                 flight.setDepartureTime(QDateTime(QDate(1, 1, 1), time));
@@ -251,6 +254,15 @@ static Event extractEventTicketPass(KPkPass::Pass *pass, Event event)
     return event;
 }
 
+static Person extractPerson(const KPkPass::Pass *pass, Person person)
+{
+    const auto fields = pass->fields();
+    for (const auto &field : fields) {
+        person = NameOptimizer::optimizeName(field.valueDisplayString(), person);
+    }
+    return person;
+}
+
 void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_unused]] const ExtractorEngine *engine) const
 {
     const auto pass = node.content<KPkPass::Pass*>();
@@ -318,6 +330,7 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
                     {
                         auto flightRes = res.value<FlightReservation>();
                         flightRes.setReservationFor(extractBoardingPass(pass, flightRes.reservationFor().value<Flight>()));
+                        flightRes.setUnderName(extractPerson(pass, flightRes.underName().value<Person>()));
                         res = flightRes;
                         break;
                     }
@@ -340,7 +353,7 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
     node.setResult(QVector<QVariant>({res}));
 }
 
-void PkPassDocumentProcessor::postExtract(ExtractorDocumentNode &node) const
+void PkPassDocumentProcessor::postExtract(ExtractorDocumentNode &node, [[maybe_unused]] const ExtractorEngine *engine) const
 {
     const auto pass = node.content<KPkPass::Pass*>();
     if (pass->passTypeIdentifier().isEmpty() || pass->serialNumber().isEmpty()) {
