@@ -103,14 +103,15 @@ function parseHtmlCommon(doc, node, res)
             res.reservationNumber = href.match(/mailto:(\d+)-/)[1];
         } else if (aElem.attribute('universal') == 'true') {
             res.reservationFor.name = aElem.content;
-        } else if (aElem.content.match(/modify/) && href.startsWith("https:")) {
+        } else if (!res.modifyReservationUrl && href.startsWith("https:") && (href.match(/pbsource=email_change;/) || href.match(/pbsource=conf_email_modify;/))) {
             res.modifyReservationUrl = href;
         }
     }
 
     const times = doc.eval('//time');
-    res.checkinTime = times[0].attribute("datetime");
-    res.checkoutTime = times[1].attribute("datetime");
+    // chop of UTC offset if present, that is based on time of booking, not time of travel
+    res.checkinTime = times[0].attribute("datetime").substr(0, 19);
+    res.checkoutTime = times[1].attribute("datetime").substr(0, 19);
 
     const text = doc.root.recursiveContent;
     for (let locale in regExMap) {
